@@ -48,7 +48,7 @@ def declarative_base(cls=None, class_factory=None, settings=None, apps=None):
     target_metadata = []
     apps = apps or getattr(settings, 'INSTALLED_APPS', [])
     if apps:
-        for app_qualname in getattr(settings, 'INSTALLED_APPS', []):
+        for app_qualname in apps:
             orm_qualname = "%s.orm" % app_qualname
             try:
                 orm = importlib.import_module(orm_qualname)
